from setuptools import setup, find_packages
setup(
      name="xdict",
      version = "1.1.10",
      description="tools for transform between html,dict and cmdline",
      author="dapeli",
      url="https://github.com/ihgazni2/dlixhict-didactic",
      author_email='terryinzaghi@163.com', 
      license="MIT",
      long_description = "refer to .md files in https://github.com/ihgazni2/dlixhict-didactic",
      entry_points = {
         'console_scripts': [
                                'ide_apis_from_verb=xdict.bin.creat_apis_from_verb:main',
                                'ide_apis_from_strblk=xdict.bin.creat_apis_from_strblk:main',
                                'ide_indent=xdict.bin.ide_indent:main',
                                'pobj=xdict.bin.pobj:main',
                                'hentry=xdict.bin.hentry:main',
                                'jsonq=xdict.bin.jsonq:main'
                            ]
      },
      classifiers=[
          'Environment :: Console',
          'Environment :: Web Environment',
          'Intended Audience :: End Users/Desktop',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'Programming Language :: Python',
          ],
      packages= find_packages(),
      py_modules=['xdict'], 
      )


# python3 setup.py bdist --formats=tar
# python3 setup.py sdist




import re
from xdict import block
import copy
from xdict.regextool import *


def format_j_str(j_str,block_op_pairs_dict=block.get_block_op_pairs('{}[]()'),**kwargs):
    if('spaces' in kwargs):
        spaces = kwargs['spaces']
    else:
        spaces = [' ','\t']
    if('colons' in kwargs):
        colons = kwargs['colons']
    else:
        colons = [':']
    if('commas' in kwargs):
        commas = kwargs['commas']
    else:
        commas = [',']
    if('line_sps' in kwargs):
        line_sps = kwargs['line_sps']
    else:
        line_sps = ['\r','\n']
    if('quotes' in kwargs):
        quotes = kwargs['quotes']
    else:
        quotes = ['"',"'"]
    # ----------------------------------------------------------------------------------
    # __str__  will make some difference :  eval will replace \\xXX wil \xXX
    # >>> js1 = "{'\x01': '\x02'}"
    # >>> js2 = "{'\\x01': '\\x02'}"
    # >>> 
    # >>> j1 = eval(js1)
    # >>> j1
    # {'\x01': '\x02'}
    # >>> j2 = eval(js2)
    # >>> j2
    # {'\x01': '\x02'}
    # >>> j1 == j2
    # True
    # >>> js1 == js2
    # False
    # >>> js3 = j1.__str__()
    # >>> js1 == js3
    # False
    # >>> js2 == js3
    # True
    # >>> js3
    # "{'\\x01': '\\x02'}"
    # >>>
    # format step 1: remove functinal-spaces(spaces not in quote) and functional-line_sp
    regex_remove_spaces = get_rm_regexp(spaces)
    j_str = regex_remove_spaces.sub("",j_str)
    regex_remove_line_sps = get_rm_regexp(line_sps)
    j_str = regex_remove_line_sps.sub("",j_str)
    # format step 2: replace functional-colons with "<colon> ",replace functional-sps with "<sp> \n"
    colon_and_sps = copy.copy(colons)
    colon_and_sps.extend(commas)
    insert_space_regexp = get_insert_space_regexp(colon_and_sps)
    j_str = re.sub(insert_space_regexp,r'\g<0> ',j_str)
    # format step 3: seperate each elements in one line
    j_str = j_str.replace(", ",", \n")
    # format step 4: seerate recursive element in one new line 
    for i in range(1,block_op_pairs_dict.__len__()+1):
        j_str = j_str.replace(block_op_pairs_dict[i][0],''.join(("\n",block_op_pairs_dict[i][0],"\n")))
        j_str = j_str.replace(block_op_pairs_dict[i][1],''.join(("\n",block_op_pairs_dict[i][1],"\n")))
    j_str = j_str.replace("\n\n","\n")
    # format step 5: move empty to one line 
    # such as {} [] ()
    for i in range(1,block_op_pairs_dict.__len__()+1):
        j_str = j_str.replace(
            ''.join((block_op_pairs_dict[i][0],'\n',block_op_pairs_dict[i][1])),
            ''.join((block_op_pairs_dict[i][0],block_op_pairs_dict[i][1]))
        )
    # format step 6: 
    j_str = j_str.replace("\n,",",")
    j_str = j_str.strip("\n")
    j_str = j_str.replace("\n\n","\n")
    return(j_str)



def get_block_op_pairs(pairs_str):
    '''
        # operators ,such as {} [] ()  ......could be user-defined
        # >>> get_block_op_pairs("{}[]")
        # {1: ('{', '}'), 2: ('[', ']')}
        # >>> get_block_op_pairs("{}[]()")
        # {1: ('{', '}'), 2: ('[', ']'), 3: ('(', ')')}
        # >>> get_block_op_pairs("{}[]()<>")
        # {1: ('{', '}'), 2: ('[', ']'), 3: ('(', ')'), 4: ('<', '>')}
    '''
    pairs_str_len = pairs_str.__len__()
    pairs_len = pairs_str_len // 2
    pairs_dict = {}
    for i in range(1,pairs_len +1):
        pairs_dict[i] = pairs_str[i*2-2],pairs_str[i*2-1]
    return(pairs_dict)


def is_lop(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
    # is_lop('{',block_op_pairs_dict)
    # is_lop('[',block_op_pairs_dict)
    # is_lop('}',block_op_pairs_dict)
    # is_lop(']',block_op_pairs_dict)
    # is_lop('a',block_op_pairs_dict)
    '''
    for i in range(1,block_op_pairs_dict.__len__()+1):
        if(ch == block_op_pairs_dict[i][0]):
            return(True)
        else:
            pass
    return(False)


def is_rop(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
        # is_rop('{',block_op_pairs_dict)
        # is_rop('[',block_op_pairs_dict)
        # is_rop('}',block_op_pairs_dict)
        # is_rop(']',block_op_pairs_dict)
        # is_rop('a',block_op_pairs_dict)
    '''
    for i in range(1,block_op_pairs_dict.__len__()+1):
        if(ch == block_op_pairs_dict[i][1]):
            return(True)
        else:
            pass
    return(False)


def is_op(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
        # is_op('{',block_op_pairs_dict)
        # is_op('[',block_op_pairs_dict)
        # is_op('}',block_op_pairs_dict)
        # is_op(']',block_op_pairs_dict)
        # is_op('a',block_op_pairs_dict)
    '''
    for i in range(1,block_op_pairs_dict.__len__()+1):
        if(ch == block_op_pairs_dict[i][0]):
            return(-1)
        elif(ch == block_op_pairs_dict[i][1]):
            return(1)
        else:
            pass
    return(0)


def is_op_pair(ch1,ch2,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
        # is_op_pair('{','}',block_op_pairs_dict)
        # is_op_pair('[',']',block_op_pairs_dict)
        # is_op_pair('}','{',block_op_pairs_dict)
        # is_op_pair(']','[',block_op_pairs_dict)
        # is_op_pair('{',']',block_op_pairs_dict)
        # is_op_pair('a','a',block_op_pairs_dict)
    '''
    x1,y1 = which_op(ch1,block_op_pairs_dict)
    x2,y2 = which_op(ch2,block_op_pairs_dict)
    if((x1 == -1) | (x2 == -1)):
        return(False)
    elif((x1 == x2) & (not(y1 == y2))):
        return(True)
    else:
        return(False)


def which_op(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
        # which_op('{',block_op_pairs_dict)
        # which_op('[',block_op_pairs_dict)
        # which_op('}',block_op_pairs_dict)
        # which_op(']',block_op_pairs_dict)
        # which_op('a',block_op_pairs_dict)
    '''
    for i in range(1,block_op_pairs_dict.__len__()+1):
        if(ch == block_op_pairs_dict[i][0]):
            return((i,0))
        elif(ch == block_op_pairs_dict[i][1]):
            return((i,1))
        else:
            pass
    return((-1,-1))



def is_ordered_op_pair(ch1,ch2,block_op_pairs_dict=get_block_op_pairs('{}[]()')):
    '''
        # is_Strict_Pair('{','}',block_op_pairs_dict)
        # is_Strict_Pair('[',']',block_op_pairs_dict)
        # is_Strict_Pair('}','{',block_op_pairs_dict)
        # is_Strict_Pair(']','[',block_op_pairs_dict)
        # is_Strict_Pair('{',']',block_op_pairs_dict)
        # is_Strict_Pair('a','a',block_op_pairs_dict)
    '''
    x1,y1 = which_op(ch1,block_op_pairs_dict)
    x2,y2 = which_op(ch2,block_op_pairs_dict)
    if((x1 == -1) | (x2 == -1)):
        return(False)
    elif((x1 == x2) & (y1 == 0)& (y2 == 1)):
        return(True)
    else:
        return(False)


def is_non_ordered_op(ch,
        block_op_pairs_dict=get_block_op_pairs('{}[]()'),
        block_non_ordered_op_pairs_dict=get_block_op_pairs('{}')):
    if(is_op(ch,block_op_pairs_dict)):
        for i in range(1,block_non_ordered_op_pairs_dict.__len__()+1):
            if(ch == block_non_ordered_op_pairs_dict[i][0]):
                return(-1)
            elif(ch == block_non_ordered_op_pairs_dict[i][1]):
                return(1)
            else:
                return(0)
    else:
        return(0)






def get_jdict_token_set(**kwargs):
    '''
        from xdict.jprint import get_jdict_token_set
        get_jdict_token_set(quotes_pairs_dict={1: ('"', '"'), 2: ("<", ">")})
    '''
    spaces = eftl.dflt_kwargs("spaces",[' ','\t'],**kwargs)
    colons = eftl.dflt_kwargs("colons",[':'],**kwargs)
    commas = eftl.dflt_kwargs("commas",[','],**kwargs)
    line_sps = eftl.dflt_kwargs("line_sps",['\r','\n'],**kwargs)
    block_op_pairs_dict = eftl.dflt_kwargs("block_op_pairs_dict",block.get_block_op_pairs('{}[]()'),**kwargs)
    quotes_pairs_dict = eftl.dflt_kwargs("quotes_pairs_dict",quote.get_quotes_pairs('""\'\''),**kwargs)
    lquotes,rquotes,quotes = quote.get_lrquotes(quotes_pairs_dict)
    path_sps = eftl.dflt_kwargs("path_sps",['/'])
    #######
    d = {}
    s = set({})
    def add_bi_table(s,d,x):
        for each in x:
            k = each
            v = escape.html_number_escape_str(k)
            d[k] = v
            d[v] = k
            s.add(k)
    add_bi_table(s,d,spaces)
    add_bi_table(s,d,colons)
    add_bi_table(s,d,commas)
    add_bi_table(s,d,line_sps)
    add_bi_table(s,d,lquotes)
    add_bi_table(s,d,rquotes)
    add_bi_table(s,d,path_sps)
    for i in range(1,block_op_pairs_dict.__len__()+1):
        s.add(block_op_pairs_dict[i][0])
        s.add(block_op_pairs_dict[i][1])
        recover_token_l = escape.html_number_escape_str(block_op_pairs_dict[i][0])
        recover_token_r = escape.html_number_escape_str(block_op_pairs_dict[i][1])
        d[block_op_pairs_dict[i][0]] = recover_token_l 
        d[block_op_pairs_dict[i][1]] = recover_token_r
        d[recover_token_l] = block_op_pairs_dict[i][0]
        d[recover_token_r] = block_op_pairs_dict[i][1]
    return({'token_set':s,'replace_ref_dict':d})




from xdict.jprint import pobj
from xdict.jprint import pdir
from xdict.cmdline import Hentry
from efuntool.efuntool import dflt_sysargv
import sys
from efdir import fs

html_text = fs.rfile(sys.argv[1])
match = dflt_sysargv('',2)
style = dflt_sysargv('flat',3)
# init a Hentry 
def main():
    htry = Hentry(html_text=html_text)
    html_entry = htry.query(match,style=style)




def help(fname=None):
    if(fname == None):
        print('''html_number_escape_char(ch)''')
        print('''html_number_escape_str(s)''')
        print('''get_block_op_pairs(pairs_str)''')
        print('''get_jdict_token_set(**kwargs)''')
        print('''convert_token_in_quote(j_str,**kwargs)''')
        print('''format_j_str(j_str,block_op_pairs_dict=get_block_op_pairs('{}[]()'),**kwargs)''')
        print('''is_lop(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''is_rop(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''is_op(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''which_op(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''is_op_pair(ch1,ch2,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''is_ordered_op_pair(ch1,ch2,block_op_pairs_dict=get_block_op_pairs('{}[]()'))''')
        print('''is_comma(ch,commas=[','])''')
        print('''is_colon(ch,colons=[':'])''')
        print('''is_non_ordered_op(ch,block_op_pairs_dict=get_block_op_pairs('{}[]()'),block_non_ordered_op_pairs_dict=get_block_op_pairs('{}'))''')
        print('''get_next_char_level_in_j_str(curr_lv,curr_seq,j_str,block_op_pairs_dict=get_block_op_pairs("{}[]()"))''')
        print('''get_j_str_lvs_dict(j_str,block_op_pairs_dict=get_block_op_pairs("{}[]()"))''')
        print('''get_line_start_index_in_j_str(orig_lines)''')
        print('''line_to_path_init(line,block_op_pairs_dict = get_block_op_pairs("{}[]()"),sp='/',commas=[','],colons=[':'])''')
        print('''line_to_path(line,curr_lv,prev_lv,prev_path,block_op_pairs_dict= get_block_op_pairs("{}[]()"),sp='/',commas=[','],colons=[':'])''')
        print('''get_print_lines_and_paths(j_str,**kwargs)''')
        print('''get_line_color_sec(line,path,**kwargs)''')
        print('''get_dynamic_indent_j_str(j_str,**kwargs)''')
        print('''print_j_str(j_str,**kwargs)''')
        print('''pobj(obj,**kwargs)''')
        print('''pdir(obj,**kwargs)''')
    elif(fname == "get_block_op_pairs"):
        info = '''PARAMS: pairs_str = "{}[]()"
                  EXEC:   get_block_op_pairs(pairs_str)
                  RESULT: {
                              1: ('{', '}'), 
                              2: ('[', ']'), 
                              3: ('(', ')')
                          }
               '''
        print(info)
        return(True)
    elif(fname == "get_jdict_token_set"):
        info = '''get_jdict_token_set(
                   spaces = [' ','\t'],
                   colons = [':'],
                   commas = [','],
                   path_sps = ['/'],
                   line_sps = ['\r','\n'],
                   block_op_pairs_dict={1: ('{', '}'), 2: ('[', ']'), 3: ('(', ')')},
                   quotes_pairs_dict={1: ('"', '"'), 2: ("'", "'")}
                   )
               '''
        print(info)
        return(True)
    elif(fname == "convert_token_in_quote"):
        info = '''convert_token_in_quote(       
                   spaces = [' ','\t'],
                   colons = [':'],
                   commas = [','],
                   path_sps = ['/'],
                   line_sps = ['\r','\n'],
                   block_op_pairs_dict={1: ('{', '}'), 2: ('[', ']'), 3: ('(', ')')},
                   quotes_pairs_dict={1: ('"', '"'), 2: ("'", "'")}
                   )
                '''
        print(info)
        return(True)
    else:
        print("NOT founded")
        #edit distance
        return(False)
